SymPy Papers
------------

A list of papers which either use or mention SymPy, as well as presentations
given about SymPy at conferences can be seen at `SymPy Papers
<https://github.com/sympy/sympy/wiki/SymPy-Papers>`_.

Planet SymPy
------------

We have a blog aggregator at http://planet.sympy.org.

SymPy logos
-----------

SymPy has a collection of official logos, which can be accessed here:

https://github.com/sympy/sympy/tree/master/doc/logo

The license of all the logos is the same as SymPy: BSD. See the LICENSE file in
the trunk for more information.

Projects using SymPy
--------------------

This is an (incomplete) list of projects that use SymPy. If you use SymPy in
your project, please let us know on our mailinglist_, so that we can add your
project here as well.

* `SfePy <http://sfepy.org/>`_ (simple finite elements in Python)
* `Quameon <http://quameon.sourceforge.net/>`_ (Quantum Monte Carlo in Python)

.. _mailinglist:        http://groups.google.com/group/sympy

Blogs, News, Magazines
----------------------

You can see a list of blogs/news/magazines mentioning SymPy (that we know of) on
our `wiki page <https://github.com/sympy/sympy/wiki/SymPy-in-the-news>`_.
